@@ -104,6 +104,8 @@ merge.icm <- function(x, y, ...) {
 #' @param keep.nwstats If \code{TRUE}, keep the network statistics (as set by
 #'        the \code{nwstats.formula} parameter in \code{control.netsim}) from
 #'        the original \code{x} and \code{y} elements.
+#' @param keep.summary.stats If \code{TRUE}, keep the summary statistics from
+#'        the original \code{x} and \code{y} elements.
 #' @param keep.other If \code{TRUE}, keep the other simulation elements (as set
 #'        by the \code{save.other} parameter in \code{control.netsim}) from the
 #'        original \code{x} and \code{y} elements.
@@ -154,8 +156,8 @@ merge.icm <- function(x, y, ...) {
 #' z$epi
 #'
 merge.netsim <- function(x, y, keep.transmat = TRUE, keep.network = TRUE,
-                         keep.nwstats = TRUE, keep.other = TRUE,
-                         param.error = TRUE, ...) {
+                         keep.nwstats = TRUE, keep.summary.stats = TRUE,
+                         keep.other = TRUE, param.error = TRUE, ...) {
 
   ## Check structure
   if (length(x) != length(y) || !identical(names(x), names(y))) {
@@ -169,19 +171,13 @@ merge.netsim <- function(x, y, keep.transmat = TRUE, keep.network = TRUE,
     stop("x and y have different structure")
   }
 
-  # Override environment of nwstats.formula
-  if (!is.null(x$control$nwstats.formula) &
-      !is.null(y$control$nwstats.formula)) {
-    environment(x$control$nwstats.formula) <-
-      environment(y$control$nwstats.formula) <- environment()
-  }
-
-
   ## Check params
   check1 <- identical(x$param, y$param)
-  check2 <- identical(x$control[-which(names(x$control) == "nsims")],
-                      y$control[-which(names(y$control) == "nsims")])
+  check2 <- identical(x$control[-which(names(x$control) %in% c("nsims","monitors","nwstats.formula"))],
+                      y$control[-which(names(y$control) %in% c("nsims","monitors","nwstats.formula"))])
 
+  ## handle formulas separately due to environments
+  check2 <- check2 && isTRUE(all.equal(x$control$monitors, y$control$monitors)) && isTRUE(all.equal(x$control$nwstats.formula, y$control$nwstats.formula))
 
   if (check1 == FALSE && param.error == TRUE) {
     stop("x and y have different parameters")
@@ -232,8 +228,7 @@ merge.netsim <- function(x, y, keep.transmat = TRUE, keep.network = TRUE,
 
 
   ## Network statistics
-  if (keep.nwstats ==
-      TRUE & !is.null(x$stats$nwstats) & !is.null(y$stats$nwstats)) {
+  if (keep.nwstats == TRUE & !is.null(x$stats$nwstats) & !is.null(y$stats$nwstats)) {
     for (i in new.range) {
       z$stats$nwstats[[i]] <- y$stats$nwstats[[i - x$control$nsims]]
       if (!is.null(z$stats$nwstats)) {
