@@ -143,7 +143,9 @@
 #' coef.diss <- dissolution_coefs(dissolution = ~offset(edges), duration = 20)
 #' est <- netest(nw, formation, target.stats, coef.diss, verbose = FALSE)
 #'
-#' # Random epidemic parameter list
+#' # Random epidemic parameter list (here act.rate values are sampled uniformly
+#' # with helper function param_random, and inf.prob follows a general Beta
+#' # distribution with the parameters shown below)
 #' my_randoms <- list(
 #'   act.rate = param_random(1:3),
 #'   inf.prob = function() rbeta(1, 1, 2)
@@ -151,16 +153,22 @@
 #'
 #' # Parameters, initial conditions, and control settings
 #' param <- param.net(rec.rate = 0.02, random.params = my_randoms)
+#'
+#' # Printing parameters shows both fixed and and random parameter functions
+#' param
+#'
+#' # Set initial conditions and controls
 #' init <- init.net(i.num = 10, r.num = 0)
-#' control <- control.net(type = "SIR", nsteps = 100, nsims = 5,
-#'                        resimulate.network = FALSE, tergmLite = FALSE)
+#' control <- control.net(type = "SIR", nsteps = 10, nsims = 3, verbose = FALSE)
 #'
 #' # Simulate the model
 #' sim <- netsim(est, param, init, control)
 #'
-#' # Print and plot
+#' # Printing the sim object shows the randomly drawn values for each simulation
 #' sim
-#' plot(sim)
+#'
+#' # These are available to access here
+#' sim$param$random.params.values
 #'
 param.net <- function(inf.prob, inter.eff, inter.start, act.rate, rec.rate,
                       a.rate, ds.rate, di.rate, dr.rate, inf.prob.g2,
@@ -184,6 +192,19 @@ param.net <- function(inf.prob, inter.eff, inter.start, act.rate, rec.rate,
     }
   }
 
+  ## random_params checks
+   if ("random.params" %in% names.dot.args) {
+     for (nm in names(p[["random.params"]])) {
+       if (nm %in% names(p)) {
+        warning(
+          "The parameter `", nm, "` is defined twice, once as fixed",
+          " and once as a random parameter.\n Only the random parameter",
+          " definition will be used."
+        )
+       }
+     }
+   }
+
   ## Defaults and Checks
   if ("b.rate" %in% names.dot.args) {
     p$a.rate <- dot.args$b.rate
@@ -340,6 +361,8 @@ param_random <- function(values, prob = NULL) {
 #' @export
 #'
 #' @examples
+#' \dontrun{
+#'
 #' # Define random parameter list
 #' my_randoms <- list(
 #'   act.rate = param_random(c(0.25, 0.5, 0.75)),
@@ -351,8 +374,15 @@ param_random <- function(values, prob = NULL) {
 #'   )
 #' )
 #'
-#' # Parameter model with deterministic and random parameters
+#' # Parameter model with fixed and random parameters
 #' param <- param.net(inf.prob = 0.3, random.params = my_randoms)
+#'
+#' # Below, `tx.prob` is set first to 0.3 then assigned a random value using
+#' # the function from `my_randoms`. A warning notifying of this overwrite is
+#' # therefore produced.
+#' param <- param.net(tx.prob = 0.3, random.params = my_randoms)
+#'
+
 #'
 #' # Parameters are drawn automatically in netsim by calling the function
 #' # within netsim_loop. Demonstrating draws here but this is not used by
@@ -360,6 +390,8 @@ param_random <- function(values, prob = NULL) {
 #' paramDraw <- generate_random_params(param, verbose = TRUE)
 #' paramDraw
 #'
+#' }
+#'
 generate_random_params <- function(param, verbose = FALSE) {
   if (is.null(param$random.params) || length(param$random.params) == 0) {
     return(param)
@@ -378,11 +410,17 @@ generate_random_params <- function(param, verbose = FALSE) {
     stop("all elements of `random.params` must be functions")
   }
 
-  param[rng_names] <- lapply(param$random.params, do.call, args = list())
+  rng_values <- list()
+  rng_values[rng_names] <- lapply(param$random.params, do.call, args = list())
+  for (nm in rng_names) {
+    param[nm] <- rng_values[nm]
+  }
+  param$random.params.values <- rng_values
+
   if (verbose == TRUE) {
     msg <-
      "The following values were randomly generated for the given parameters: \n"
-    msg <- c(msg, paste0("`", rng_names, "`: ", param[rng_names], "\n"))
+    msg <- c(msg, paste0("`", rng_names, "`: ", rng_values, "\n"))
     message(msg)
   }
 
@@ -545,20 +583,17 @@ init.net <- function(i.num, r.num, i.num.g2, r.num.g2,
 #'        listed, then the built-in modules in their order of the function
 #'        listing. The \code{initialize.FUN} will always be run first and the
 #'        \code{verbose.FUN} always last.
-#' @param set.control.ergm Control arguments passed to simulate.ergm. See the
-#'        help file for \code{\link{netdx}} for details and examples on
-#'        specifying this parameter.
-#' @param set.control.stergm Control arguments passed to simulate.stergm. See
-#'        the help file for \code{\link{netdx}} for details and examples on
-#'        specifying this parameter.
 #' @param save.nwstats If \code{TRUE}, save network statistics in a data frame.
 #'        The statistics to be saved are specified in the \code{nwstats.formula}
 #'        argument.
-#' @param save.transmat If \code{TRUE}, complete transmission matrix is saved at
-#'        simulation end. Default of \code{TRUE}.
 #' @param nwstats.formula A right-hand sided ERGM formula that includes network
 #'        statistics of interest, with the default to the formation formula
 #'        terms.
+#' @param save.network If \code{TRUE}, networkDynamic/network object is
+#'        saved at simulation end. Implicit reset to \code{FALSE} if
+#'        \code{tergmLite = TRUE} (because network history not saved with tL).
+#' @param save.transmat If \code{TRUE}, complete transmission matrix is saved at
+#'        simulation end. Default of \code{TRUE}.
 #' @param save.other A vector of elements on the \code{dat} master data list
 #'        to save out after each simulation. One example for base models is
 #'        the attribute list, "attr", at the final time step.
@@ -574,6 +609,21 @@ init.net <- function(i.num, r.num, i.num.g2, r.num.g2,
 #'        modules specified.
 #' @param raw.output If \code{TRUE}, \code{netsim} will output a list of nestsim
 #'        data (one per simulation) instead of a formatted \code{netsim} object.
+#' @param tergmLite.track.duration logical; to track duration information
+#'        (\code{time} and \code{lasttoggle}) for \code{tergm} models in
+#'        \code{tergmLite} simulations. If \code{TRUE}, the \code{time} and
+#'        \code{lasttoggle} values are initialized from the network attributes
+#'        of the networks passed to \code{init_tergmLite}, with \code{time}
+#'        defaulting to \code{0} and \code{lasttoggle} defaulting to all
+#'        \code{lasttoggle} times unspecified (effectively \code{-INT_MAX/2}).
+#' @param set.control.ergm Control arguments passed to \code{simulate.ergm}. See
+#'        the help file for \code{\link{netdx}} for details and examples on
+#'        specifying this parameter.
+#' @param set.control.stergm Control arguments passed to \code{simulate.stergm}.
+#'        See the help file for \code{\link{netdx}} for details and examples on
+#'        specifying this parameter.
+#' @param mcmc.control.tergm,mcmc.control.ergm Control arguments for network
+#'        simulation in \code{tergmLite}.
 #' @param ... Additional control settings passed to model.
 #'
 #' @details
@@ -648,16 +698,20 @@ control.net <- function(type,
                         prevalence.FUN = prevalence.net,
                         verbose.FUN = verbose.net,
                         module.order = NULL,
-                        set.control.ergm,
-                        set.control.stergm,
                         save.nwstats = TRUE,
-                        save.transmat = TRUE,
                         nwstats.formula = "formation",
+                        save.transmat = TRUE,
+                        save.network,
                         save.other,
                         verbose = TRUE,
                         verbose.int = 1,
                         skip.check = FALSE,
                         raw.output = FALSE,
+                        tergmLite.track.duration = FALSE,
+                        set.control.ergm = control.simulate.ergm(MCMC.burnin = 2e5),
+                        set.control.stergm = control.simulate.network(MCMC.burnin.min = 1000),
+                        mcmc.control.ergm = control.simulate.formula(),
+                        mcmc.control.tergm = control.simulate.formula.tergm(),
                         ...) {
 
   # Get arguments
@@ -715,11 +769,6 @@ control.net <- function(type,
   p$user.mods <- grep(".FUN", names(dot.args), value = TRUE)
   p$f.names <- c(p$bi.mods, p$user.mods)
 
-  # Temporary until we develop a nwstats fix for tergmLite
-  if (tergmLite == TRUE) {
-    p$save.nwstats <- FALSE
-  }
-
   ## Defaults and checks
 
   #Check whether any base modules have been redefined by user (note: must come
@@ -765,15 +814,20 @@ control.net <- function(type,
     }
   }
 
-  if (is.null(p$set.control.stergm)) {
-    p$set.control.stergm <- control.simulate.network(MCMC.burnin.min = 1000)
+  if (is.null(p$save.network)) {
+    p$save.network <- TRUE
   }
-  if (is.null(p$set.control.ergm)) {
-    p$set.control.ergm <- control.simulate.ergm(MCMC.burnin = 2e5)
+  if (p$tergmLite == TRUE) {
+    p$save.network <- FALSE
+  }
+  if (p$tergmLite == TRUE & p$resimulate.network == FALSE) {
+    message("Because tergmLite = TRUE, resetting resimulate.network = TRUE",
+            call. = FALSE)
+    p$resimulate.network <- TRUE
   }
 
   ## Output
-  class(p) <- c("control.net", "list")
+  p <- set.control.class("control.net", p)
   return(p)
 }
 
@@ -797,6 +851,7 @@ control.net <- function(type,
 #' @keywords internal
 #'
 crosscheck.net <- function(x, param, init, control) {
+  check.control.class("net", "EpiModel crosscheck.net")
 
   if (!is.null(control$type) && length(control$user.mods) == 0) {
 
