@@ -24,6 +24,7 @@ nwupdate.net <- function(dat, at) {
 
   # statOnNw <- "status" %in% dat$temp$nwterms
   resimulate.network <- get_control(dat, "resimulate.network")
+  isTERGM <- get_control(dat, "isTERGM")
 
   ## Vital Dynamics
   arrivals <- which(active == 1 & entrTime == at)
@@ -44,31 +45,42 @@ nwupdate.net <- function(dat, at) {
     }
     if (tergmLite == FALSE) {
       dat$nw[[1]] <- add.vertices(dat$nw[[1]], nv = nArrivals)
-      dat$nw[[1]] <- activate.vertices(dat$nw[[1]], onset = at,
-                                       terminus = Inf, v = arrivals)
-      dat$nw[[1]] <- activate.vertex.attribute(dat$nw[[1]],
-                                               prefix = "testatus",
-                                               value = status[arrivals],
-                                               onset = at, terminus = Inf,
-                                               v = arrivals)
+      if (isTERGM == TRUE) {
+        dat$nw[[1]] <- activate.vertices(dat$nw[[1]], onset = at,
+                                         terminus = Inf, v = arrivals)
+        dat$nw[[1]] <- activate.vertex.attribute(dat$nw[[1]],
+                                                 prefix = "testatus",
+                                                 value = status[arrivals],
+                                                 onset = at, terminus = Inf,
+                                                 v = arrivals)
+      }
     }
     if (tergmLite == TRUE) {
       dat$el[[1]] <- add_vertices(dat$el[[1]], nv = nArrivals)
     }
-
   }
 
 
   ## Departures
   if (length(departures) > 0) {
     if (tergmLite == FALSE) {
-      dat$nw[[1]] <- deactivate.vertices(dat$nw[[1]], onset = at,
-                                         terminus = Inf, v = departures,
-                                         deactivate.edges = TRUE)
+      if (isTERGM == TRUE) {
+        dat$nw[[1]] <- deactivate.vertices(dat$nw[[1]], onset = at,
+                                           terminus = Inf, v = departures,
+                                           deactivate.edges = TRUE)
+      } else {
+        dat$nw[[1]] <- delete.vertices(dat$nw[[1]], vid = departures)
+        dat <- delete_attr(dat, departures)
+      }
     }
     if (tergmLite == TRUE) {
       dat <- delete_attr(dat, departures)
       dat$el[[1]] <- delete_vertices(dat$el[[1]], departures)
+
+      if (dat$control$tergmLite.track.duration) {
+        dat$p[[1]]$state$nw0 %n% "lasttoggle" <-
+          delete_vertices(dat$p[[1]]$state$nw0 %n% "lasttoggle", departures)
+      }
     }
   }
 
@@ -78,7 +90,7 @@ nwupdate.net <- function(dat, at) {
   }
 
   ## Update temporally extended disease status
-  if (tergmLite == FALSE) {
+  if (tergmLite == FALSE & isTERGM == TRUE) {
     dat$nw[[1]] <- activate.vertex.attribute(dat$nw[[1]],
                                              prefix = "testatus",
                                              value = status,
@@ -86,6 +98,15 @@ nwupdate.net <- function(dat, at) {
                                              terminus = Inf)
   }
 
+  # Record network in nw_list for x-sect ERGM simulations
+  if (tergmLite == FALSE & isTERGM == FALSE & resimulate.network == TRUE) {
+    dat$temp$nw_list[[at]] <- dat$nw[[1]]
+  }
+  if (tergmLite == FALSE & isTERGM == FALSE & resimulate.network == FALSE) {
+    dat$temp$nw_list[[at]] <- set_vertex_attribute(dat$temp$nw_list[[at]],
+                                                   "status", status)
+  }
+
   ## Output
   return(dat)
 }
