@@ -125,7 +125,7 @@ print.netsim <- function(x, formation.stats = FALSE, digits = 3, ...) {
     simnames <- "sim1"
   }
   if (nsims == 2) {
-    simnames <- "sim1 s.g2"
+    simnames <- "sim1 sim2"
   }
   if (nsims > 2) {
     simnames <- paste0("sim1 ... sim", nsims)
@@ -142,20 +142,9 @@ print.netsim <- function(x, formation.stats = FALSE, digits = 3, ...) {
   cat("\nNo. time steps:", x$control$nsteps)
   cat("\nNo. NW groups:", x$param$groups)
 
-  cat("\n\nModel Parameters")
-  cat("\n-----------------------\n")
-  pToPrint <- which(!(names(x$param) %in% c("groups", "vital")))
-  for (i in pToPrint) {
-    if (class(x$param[[i]]) == "numeric" && length(x$param[[i]]) > 5) {
-      cat(names(x$param)[i], "=", x$param[[i]][1:3], "...", fill = 80)
-    } else if (class(x$param[[i]]) == "data.frame") {
-      cat(names(x$param)[i], "= <data.frame>\n")
-    } else if (class(x$param[[i]]) == "list") {
-      cat(names(x$param)[i], "= <list>\n")
-    } else {
-      cat(names(x$param)[i], "=", x$param[[i]], fill = 80)
-    }
-  }
+  # Parameters
+  cat("\n\n")
+  print(x$param)
 
   if (is.null(x$control$type)) {
     cat("\nModel Functions")
@@ -163,7 +152,7 @@ print.netsim <- function(x, formation.stats = FALSE, digits = 3, ...) {
     for (i in 1:length(x$control$f.names)) {
       cat(x$control$f.names[i], "\n")
     }
-    cat("\n")
+    # cat("\n")
   }
 
   cat("\nModel Output")
@@ -243,9 +232,10 @@ print.netsim <- function(x, formation.stats = FALSE, digits = 3, ...) {
     cat("\n----------------------- \n")
     print(as.data.frame(round(as.matrix(x$stats.table.formation),
                               digits = digits)))
-    cat("")
+    cat("\n")
   }
 
+  cat("\n")
   invisible()
 }
 
@@ -265,6 +255,25 @@ print.disscoef <- function(x, ...) {
   invisible()
 }
 
+#' Format one parameter for printing with the `print.param.xxx` functions
+#'
+#' @param param_name The name of the parameter to print
+#' @param param_value The value of the parameter to print
+#'
+#' @keywords internal
+format_param <- function(param_name, param_value) {
+  if (is.numeric(param_value) && length(param_value) > 10) {
+    cat(param_name, "=", param_value[1:10], "...", fill = 80)
+  } else if (is.data.frame(param_value)) {
+    cat(param_name, "= <data.frame>\n")
+  } else if (is.list(param_value)) {
+    cat(param_name, "= <list>\n")
+  } else if (inherits(param_value, "lm")) {
+    cat(param_name, "= <lm/glm>\n")
+  } else {
+    cat(param_name, "=", param_value, fill = 80)
+  }
+}
 
 #' @export
 print.param.dcm <- function(x, ...) {
@@ -274,15 +283,7 @@ print.param.dcm <- function(x, ...) {
   cat("DCM Parameters")
   cat("\n===========================\n")
   for (i in pToPrint) {
-    if (class(x[[i]]) %in% c("integer", "numeric") && length(x[[i]]) > 10) {
-      cat(names(x)[i], "=", x[[i]][1:5], "...", fill = 80)
-    } else if (class(x[[i]]) == "data.frame") {
-      cat(names(x)[i], "= <data.frame>\n")
-    } else if (class(x[[i]]) == "list") {
-      cat(names(x)[i], "= <list>\n")
-    } else {
-      cat(names(x)[i], "=", x[[i]], fill = 80)
-    }
+    format_param(names(x)[i], x[[i]])
   }
 
   invisible()
@@ -296,15 +297,7 @@ print.param.icm <- function(x, ...) {
   cat("ICM Parameters")
   cat("\n===========================\n")
   for (i in pToPrint) {
-    if (class(x[[i]]) %in% c("integer", "numeric") && length(x[[i]]) > 10) {
-      cat(names(x)[i], "=", x[[i]][1:5], "...", fill = 80)
-    } else if (class(x[[i]]) == "data.frame") {
-      cat(names(x)[i], "= <data.frame>\n")
-    } else if (class(x[[i]]) == "list") {
-      cat(names(x)[i], "= <list>\n")
-    } else {
-      cat(names(x)[i], "=", x[[i]], fill = 80)
-    }
+    format_param(names(x)[i], x[[i]])
   }
 
   invisible()
@@ -313,24 +306,43 @@ print.param.icm <- function(x, ...) {
 #' @export
 print.param.net <- function(x, ...) {
 
-  pToPrint <- which(!(names(x) %in% c("vital")))
+  randoms <- c("random.params", "random.params.values")
+  pToPrint <- which(!(names(x) %in% c("vital", randoms)))
+  rng_values <- list()
+  rng_defs <- NULL
 
-  cat("Network Model Parameters")
-  cat("\n===========================\n")
+  if (all(randoms %in% names(x))) {
+    rng_values <- x$random.params.values
+    pToPrint <- pToPrint[! names(x)[pToPrint] %in% names(rng_values)]
+  } else if (randoms[1] %in% names(x)) {
+    rng_defs <- names(x[[randoms[1]]])
+  }
+
+  cat("Fixed Parameters")
+    cat("\n---------------------------\n")
   for (i in pToPrint) {
-    if (class(x[[i]]) %in% c("integer", "numeric") && length(x[[i]]) > 10) {
-      cat(names(x)[i], "=", x[[i]][1:5], "...", fill = 80)
-    } else if (inherits(x[[i]], "data.frame")) {
-      cat(names(x)[i], "= <data.frame>\n")
-    } else if (inherits(x[[i]], "list")) {
-      cat(names(x)[i], "= <list>\n")
-    } else if (inherits(x[[i]], "lm")) {
-      cat(names(x)[i], "= <lm/glm>\n")
-    } else {
-      cat(names(x)[i], "=", x[[i]], fill = 80)
+    format_param(names(x)[i], x[[i]])
+  }
+
+  if (!is.null(rng_defs)) {
+    cat("\nRandom Parameters")
+    cat("\n(Not drawn yet)")
+    cat("\n---------------------------\n")
+    for (prm in rng_defs) {
+      cat(prm, " = <function>\n")
     }
   }
 
+  if (length(rng_values) > 0) {
+    cat("\nRandom Parameters")
+    cat("\n---------------------------\n")
+    for (i in seq_along(rng_values)) {
+      format_param(names(rng_values)[i], rng_values[[i]])
+    }
+  }
+
+  # cat("\n")
+
   invisible()
 }
 
@@ -445,6 +457,7 @@ print.control.net <- function(x, ...) {
                       names(x) != "f.names" &
                       names(x) != "set.control.stergm" &
                       names(x) != "set.control.ergm" &
+                      !grepl("^mcmc\\.control", names(x)) &
                       !(names(x) %in% c("bi.mods", "user.mods")))
 
 
