@@ -18,14 +18,16 @@
 #' @keywords internal
 #' @export
 #'
-mcat <- function(test) { cat("\n", test, " ... ", sep = "") }
+mcat <- function(test) {
+  cat("\n", test, " ... ", sep = "")
+  }
 
 
 #' @title Test the Model Output from a Network Model
 #'
-#' @description Tests whether the model output from a network model is consistent
-#'              with key balancing equations for compartment and flow sizes for
-#'              each simulation for each time step.
+#' @description Tests whether the model output from a network model is
+#'              consistent with key balancing equations for compartment and
+#'              flow sizes for each simulation for each time step.
 #'
 #' @param x An object of class \code{netsim}.
 #'
@@ -57,9 +59,11 @@ test_net <- function(x) {
           }
         }
         if (vital == TRUE) {
-          test <- with(df, num[i] == num[i - 1] + a.flow[i] - ds.flow[i] - di.flow[i])
+          test <- with(df, num[i] == num[i - 1] + a.flow[i] -
+                         ds.flow[i] - di.flow[i])
           if (test == FALSE) stop("\nFailed *num* at SIM", s, "TIME", i)
-          test <- with(df, s.num[i] == s.num[i - 1] - si.flow[i] + a.flow[i] - ds.flow[i])
+          test <- with(df, s.num[i] == s.num[i - 1] - si.flow[i] +
+                         a.flow[i] - ds.flow[i])
           if (test == FALSE) stop("\nFailed *s.num* at SIM", s, "TIME", i)
           test <- with(df, i.num[i] == i.num[i - 1] + si.flow[i] - di.flow[i])
           if (test == FALSE) stop("\nFailed *i.num* at SIM", s, "TIME", i)
@@ -70,7 +74,8 @@ test_net <- function(x) {
             test <- df$s.num.g2[i] == df$s.num.g2[i - 1] - df$si.flow.g2[i] +
                                       df$a.flow.g2[i] - df$ds.flow.g2[i]
             if (test == FALSE) stop("\nFailed *s.num.g2* at SIM", s, "TIME", i)
-            test <- with(df, i.num.g2[i] == i.num.g2[i - 1] + si.flow.g2[i] - di.flow.g2[i])
+            test <- with(df, i.num.g2[i] == i.num.g2[i - 1] +
+                           si.flow.g2[i] - di.flow.g2[i])
             if (test == FALSE) stop("\nFailed *i.num.g2* at SIM", s, "TIME", i)
           }
         }
@@ -87,7 +92,8 @@ test_net <- function(x) {
           if (groups == 2) {
             test <- with(df, s.num.g2[i] == s.num.g2[i - 1] - si.flow.g2[i])
             if (test == FALSE) stop("\nFailed *s.num.g2* at SIM", s, "TIME", i)
-            test <- with(df, i.num.g2[i] == i.num.g2[i - 1] + si.flow.g2[i] - ir.flow.g2[i])
+            test <- with(df, i.num.g2[i] == i.num.g2[i - 1] +
+                           si.flow.g2[i] - ir.flow.g2[i])
             if (test == FALSE) stop("\nFailed *i.num.g2* at SIM", s, "TIME", i)
             test <- with(df, r.num.g2[i] == r.num.g2[i - 1] + ir.flow.g2[i])
             if (test == FALSE) stop("\nFailed *r.num.g2* at SIM", s, "TIME", i)
@@ -97,15 +103,18 @@ test_net <- function(x) {
           test <- with(df, num[i] == num[i - 1] + a.flow[i] - ds.flow[i] -
                          di.flow[i] - dr.flow[i])
           if (test == FALSE) stop("\nFailed *num* at SIM", s, "TIME", i)
-          test <- with(df, s.num[i] == s.num[i - 1] - si.flow[i] + a.flow[i] - ds.flow[i])
+          test <- with(df, s.num[i] == s.num[i - 1] - si.flow[i] +
+                         a.flow[i] - ds.flow[i])
           if (test == FALSE) stop("\nFailed *s.num* at SIM", s, "TIME", i)
-          test <- with(df, i.num[i] == i.num[i - 1] + si.flow[i] - ir.flow[i] - di.flow[i])
+          test <- with(df, i.num[i] == i.num[i - 1] + si.flow[i] -
+                         ir.flow[i] - di.flow[i])
           if (test == FALSE) stop("\nFailed *i.num* at SIM", s, "TIME", i)
           test <- with(df, r.num[i] == r.num[i - 1] + ir.flow[i] - dr.flow[i])
           if (test == FALSE) stop("\nFailed *r.num* at SIM", s, "TIME", i)
           if (groups == 2) {
-            test <- with(df, num.g2[i] == num.g2[i - 1] + a.flow.g2[i] - ds.flow.g2[i] -
-                                          di.flow.g2[i] - dr.flow.g2[i])
+            test <- with(df, num.g2[i] == num.g2[i - 1] +
+                           a.flow.g2[i] - ds.flow.g2[i] -
+                           di.flow.g2[i] - dr.flow.g2[i])
             if (test == FALSE) stop("\nFailed *num* at SIM", s, "TIME", i)
             test <- with(df, s.num.g2[i] == s.num.g2[i - 1] - si.flow.g2[i] +
                            a.flow.g2[i] - ds.flow.g2[i])
@@ -113,7 +122,8 @@ test_net <- function(x) {
             test <- with(df, i.num.g2[i] == i.num.g2[i - 1] + si.flow.g2[i] -
                                             ir.flow.g2[i] - di.flow.g2[i])
             if (test == FALSE) stop("\nFailed *i.num* at SIM", s, "TIME", i)
-            test <- with(df, r.num.g2[i] == r.num.g2[i - 1] + ir.flow.g2[i] - dr.flow.g2[i])
+            test <- with(df, r.num.g2[i] == r.num.g2[i - 1] +
+                           ir.flow.g2[i] - dr.flow.g2[i])
             if (test == FALSE) stop("\nFailed *r.num* at SIM", s, "TIME", i)
           }
         }
@@ -126,19 +136,23 @@ test_net <- function(x) {
           test <- with(df, i.num[i] == i.num[i - 1] + si.flow[i] - is.flow[i])
           if (test == FALSE) stop("\nFailed *i.num* at SIM", s, "TIME", i)
           if (groups == 2) {
-            test <- with(df, s.num.g2[i] == s.num.g2[i - 1] - si.flow.g2[i] + is.flow.g2[i])
+            test <- with(df, s.num.g2[i] == s.num.g2[i - 1] -
+                           si.flow.g2[i] + is.flow.g2[i])
             if (test == FALSE) stop("\nFailed *s.num.g2* at SIM", s, "TIME", i)
-            test <- with(df, i.num.g2[i] == i.num.g2[i - 1] + si.flow.g2[i] - is.flow.g2[i])
+            test <- with(df, i.num.g2[i] == i.num.g2[i - 1] +
+                           si.flow.g2[i] - is.flow.g2[i])
             if (test == FALSE) stop("\nFailed *i.num.g2* at SIM", s, "TIME", i)
           }
         }
         if (vital == TRUE) {
-          test <- with(df, num[i] == num[i - 1] + a.flow[i] - ds.flow[i] - di.flow[i])
+          test <- with(df, num[i] == num[i - 1] + a.flow[i] -
+                         ds.flow[i] - di.flow[i])
           if (test == FALSE) stop("\nFailed *num* at SIM", s, "TIME", i)
           test <- with(df, s.num[i] == s.num[i - 1] - si.flow[i] + is.flow[i] +
                          a.flow[i] - ds.flow[i])
           if (test == FALSE) stop("\nFailed *s.num* at SIM", s, "TIME", i)
-          test <- with(df, i.num[i] == i.num[i - 1] + si.flow[i] - is.flow[i] - di.flow[i])
+          test <- with(df, i.num[i] == i.num[i - 1] + si.flow[i] -
+                         is.flow[i] - di.flow[i])
           if (test == FALSE) stop("\nFailed *i.num* at SIM", s, "TIME", i)
           if (groups == 2) {
             test <- with(df, num.g2[i] == num.g2[i - 1] + a.flow.g2[i] -
@@ -196,9 +210,11 @@ test_icm <- function(x) {
           }
         }
         if (vital == TRUE) {
-          test <- with(df, num[i] == num[i - 1] + a.flow[i] - ds.flow[i] - di.flow[i])
+          test <- with(df, num[i] == num[i - 1] + a.flow[i] -
+                         ds.flow[i] - di.flow[i])
           if (test == FALSE) stop("\nFailed *num* at SIM", s, "TIME", i)
-          test <- with(df, s.num[i] == s.num[i - 1] - si.flow[i] + a.flow[i] - ds.flow[i])
+          test <- with(df, s.num[i] == s.num[i - 1] - si.flow[i] +
+                         a.flow[i] - ds.flow[i])
           if (test == FALSE) stop("\nFailed *s.num* at SIM", s, "TIME", i)
           test <- with(df, i.num[i] == i.num[i - 1] + si.flow[i] - di.flow[i])
           if (test == FALSE) stop("\nFailed *i.num* at SIM", s, "TIME", i)
@@ -209,7 +225,8 @@ test_icm <- function(x) {
             test <- df$s.num.g2[i] == df$s.num.g2[i - 1] - df$si.flow.g2[i] +
                                       df$a.flow.g2[i] - df$ds.flow.g2[i]
             if (test == FALSE) stop("\nFailed *s.num.g2* at SIM", s, "TIME", i)
-            test <- with(df, i.num.g2[i] == i.num.g2[i - 1] + si.flow.g2[i] - di.flow.g2[i])
+            test <- with(df, i.num.g2[i] == i.num.g2[i - 1] +
+                           si.flow.g2[i] - di.flow.g2[i])
             if (test == FALSE) stop("\nFailed *i.num.g2* at SIM", s, "TIME", i)
           }
         }
@@ -226,7 +243,8 @@ test_icm <- function(x) {
           if (groups == 2) {
             test <- with(df, s.num.g2[i] == s.num.g2[i - 1] - si.flow.g2[i])
             if (test == FALSE) stop("\nFailed *s.num.g2* at SIM", s, "TIME", i)
-            test <- with(df, i.num.g2[i] == i.num.g2[i - 1] + si.flow.g2[i] - ir.flow.g2[i])
+            test <- with(df, i.num.g2[i] == i.num.g2[i - 1] +
+                           si.flow.g2[i] - ir.flow.g2[i])
             if (test == FALSE) stop("\nFailed *i.num.g2* at SIM", s, "TIME", i)
             test <- with(df, r.num.g2[i] == r.num.g2[i - 1] + ir.flow.g2[i])
             if (test == FALSE) stop("\nFailed *r.num.g2* at SIM", s, "TIME", i)
@@ -236,23 +254,27 @@ test_icm <- function(x) {
           test <- with(df, num[i] == num[i - 1] + a.flow[i] - ds.flow[i] -
                          di.flow[i] - dr.flow[i])
           if (test == FALSE) stop("\nFailed *num* at SIM", s, "TIME", i)
-          test <- with(df, s.num[i] == s.num[i - 1] - si.flow[i] + a.flow[i] - ds.flow[i])
+          test <- with(df, s.num[i] == s.num[i - 1] - si.flow[i] +
+                         a.flow[i] - ds.flow[i])
           if (test == FALSE) stop("\nFailed *s.num* at SIM", s, "TIME", i)
-          test <- with(df, i.num[i] == i.num[i - 1] + si.flow[i] - ir.flow[i] - di.flow[i])
+          test <- with(df, i.num[i] == i.num[i - 1] + si.flow[i] -
+                         ir.flow[i] - di.flow[i])
           if (test == FALSE) stop("\nFailed *i.num* at SIM", s, "TIME", i)
           test <- with(df, r.num[i] == r.num[i - 1] + ir.flow[i] - dr.flow[i])
           if (test == FALSE) stop("\nFailed *r.num* at SIM", s, "TIME", i)
           if (groups == 2) {
-            test <- with(df, num.g2[i] == num.g2[i - 1] + a.flow.g2[i] - ds.flow.g2[i] -
-                           di.flow.g2[i] - dr.flow.g2[i])
-            if (test == FALSE) stop("\nFailed *num.g2* at SIM", s, "TIME", i, sep = " ")
+            test <- with(df, num.g2[i] == num.g2[i - 1] + a.flow.g2[i] -
+                           ds.flow.g2[i] - di.flow.g2[i] - dr.flow.g2[i])
+            if (test == FALSE) stop("\nFailed *num.g2* at SIM", s,
+                                    "TIME", i, sep = " ")
             test <- with(df, s.num.g2[i] == s.num.g2[i - 1] - si.flow.g2[i] +
                            a.flow.g2[i] - ds.flow.g2[i])
             if (test == FALSE) stop("\nFailed *s.num.g2* at SIM", s, "TIME", i)
             test <- with(df, i.num.g2[i] == i.num.g2[i - 1] + si.flow.g2[i] -
                            ir.flow.g2[i] - di.flow.g2[i])
             if (test == FALSE) stop("\nFailed *i.num.g2* at SIM", s, "TIME", i)
-            test <- with(df, r.num.g2[i] == r.num.g2[i - 1] + ir.flow.g2[i] - dr.flow.g2[i])
+            test <- with(df, r.num.g2[i] == r.num.g2[i - 1] +
+                           ir.flow.g2[i] - dr.flow.g2[i])
             if (test == FALSE) stop("\nFailed *r.num.g2* at SIM", s, "TIME", i)
           }
         }
@@ -265,19 +287,23 @@ test_icm <- function(x) {
           test <- with(df, i.num[i] == i.num[i - 1] + si.flow[i] - is.flow[i])
           if (test == FALSE) stop("\nFailed *i.num* at SIM", s, "TIME", i)
           if (groups == 2) {
-            test <- with(df, s.num.g2[i] == s.num.g2[i - 1] - si.flow.g2[i] + is.flow.g2[i])
+            test <- with(df, s.num.g2[i] == s.num.g2[i - 1] -
+                           si.flow.g2[i] + is.flow.g2[i])
             if (test == FALSE) stop("\nFailed *s.num.g2* at SIM", s, "TIME", i)
-            test <- with(df, i.num.g2[i] == i.num.g2[i - 1] + si.flow.g2[i] - is.flow.g2[i])
+            test <- with(df, i.num.g2[i] == i.num.g2[i - 1] +
+                           si.flow.g2[i] - is.flow.g2[i])
             if (test == FALSE) stop("\nFailed *i.num.g2* at SIM", s, "TIME", i)
           }
         }
         if (vital == TRUE) {
-          test <- with(df, num[i] == num[i - 1] + a.flow[i] - ds.flow[i] - di.flow[i])
+          test <- with(df, num[i] == num[i - 1] + a.flow[i] -
+                         ds.flow[i] - di.flow[i])
           if (test == FALSE) stop("\nFailed *num* at SIM", s, "TIME", i)
           test <- with(df, s.num[i] == s.num[i - 1] - si.flow[i] + is.flow[i] +
                          a.flow[i] - ds.flow[i])
           if (test == FALSE) stop("\nFailed *s.num* at SIM", s, "TIME", i)
-          test <- with(df, i.num[i] == i.num[i - 1] + si.flow[i] - is.flow[i] - di.flow[i])
+          test <- with(df, i.num[i] == i.num[i - 1] + si.flow[i] -
+                         is.flow[i] - di.flow[i])
           if (test == FALSE) stop("\nFailed *i.num* at SIM", s, "TIME", i)
           if (groups == 2) {
             test <- with(df, num.g2[i] == num.g2[i - 1] + a.flow.g2[i] -
