@@ -34,7 +34,7 @@
 #'  abline(v = 1:100, lwd = 6, col = brewer_ramp(100, pals[i]))
 #' }
 #'
-brewer_ramp <- function(n, plt, delete.lights = TRUE){
+brewer_ramp <- function(n, plt, delete.lights = TRUE) {
 
   if (n < 1) {
     stop("n must be a positive integer", call. = FALSE)
@@ -42,7 +42,8 @@ brewer_ramp <- function(n, plt, delete.lights = TRUE){
 
   bpi <- brewer.pal.info
   if (!(plt %in% row.names(bpi))) {
-    stop("plt must match an RColorBrewer palette name. See RColorBrewer::brewer.pal.info",
+    stop("plt must match an RColorBrewer palette name. See
+         RColorBrewer::brewer.pal.info",
          .call = FALSE)
   }
 
@@ -215,7 +216,8 @@ mutate_epi <- function(x, ...) {
   not.df <- which(sapply(ndat, class) != "data.frame")
   if (length(not.df) > 0) {
     for (jj in not.df) {
-      ndat[jj][[1]] <- data.frame(rep(ndat[jj][[1]], length.out = x$control$nsteps))
+      ndat[jj][[1]] <- data.frame(rep(ndat[jj][[1]],
+                                      length.out = x$control$nsteps))
       names(ndat[[jj]]) <- "run1"
     }
   }
@@ -233,8 +235,8 @@ mutate_epi <- function(x, ...) {
 #'
 #' @param vector.length Length for the output vector.
 #' @param values Values for the output vector.
-#' @param proportions Proportion distribution with one number for each value. This
-#'        must sum to 1.
+#' @param proportions Proportion distribution with one number for each value.
+#'        This must sum to 1.
 #' @param shuffled If \code{TRUE}, randomly shuffle the order of the vector.
 #'
 #' @export
@@ -251,8 +253,10 @@ apportion_lr <- function(vector.length, values,
   if (is.vector(values) == FALSE) {
     stop("argument values must be a vector")
   }
-  if (!(length(proportions) == length(values) && round(sum(proportions), 10) == 1) &&
-      (!(length(proportions) == length(values) - 1 && round(sum(proportions), 10) <= 1 &&
+  if (!(length(proportions) == length(values) && round(sum(proportions),
+                                                       10) == 1) &&
+      (!(length(proportions) == length(values) - 1 && round(sum(proportions),
+                                                            10) <= 1 &&
          round(sum(proportions), 10) >= 0))) {
     stop("error in proportions length or proportions sum")
   }
@@ -276,3 +280,23 @@ apportion_lr <- function(vector.length, values,
 
   return(result)
 }
+
+
+#' @title Message to find in which module a `condition` occured
+#'
+#' @description Returns vector of colors consistent with a high-brightness set
+#'              of colors from an \code{RColorBrewer} palette.
+#'
+#' @param cond The type of `condition` handled (message, warning, error)
+#' @param module The name of the module where the `condition` occured
+#' @param at The time step the `condition` occured
+#' @param msg The `condition`'s message
+#'
+#' @return A formatted string describing where and whe the `condition` occured
+#'         as well as the `condition`'s message.
+#'
+#' @keywords internal
+netsim_cond_msg <- function(cond, module, at, msg) {
+  paste0("A ", cond, " occured in module '", module,
+         "' at step ", at, ": \n\t", msg)
+}
